@@ -2,7 +2,8 @@ from typing import Sequence
 from datetime import datetime, time
 
 from .utils import (
-    parse_mdc_time, pack_mdc_time, parse_enum_bitmask, pack_bitmask)
+    parse_mdc_time, pack_mdc_time, parse_enum_bitmask, pack_bitmask,
+    pack_videowall_model, parse_videowall_model)
 
 
 class Field:
@@ -151,3 +152,20 @@ class IPAddress(Field):
         if not len(rv) == 4 or not all(0 <= x < 256 for x in rv):
             raise ValueError('Invalid IP address', data)
         return rv
+
+
+class VideoWallModel(Field):
+    parse_len = 1
+
+    def parse(self, data):
+        return parse_videowall_model(data[0])
+
+    def pack(self, data):
+        if isinstance(data, str):
+            rv = tuple(int(x) for x in data.split(','))
+        elif not isinstance(data, (tuple, list)):
+            raise TypeError('Video wall model must be Tuple[int, int] or'
+                            'comma-separated string')
+        if not len(rv) == 2:
+            raise ValueError('Invalid video wall model', data)
+        return pack_videowall_model(rv)
