@@ -52,3 +52,17 @@ def repr_hex(value):
 
 def parse_hex(value):
     return value and bytes(int(x, 16) for x in value.split(':')) or b''
+
+
+def parse_videowall_model(value):
+    """
+    Splits coordinates byte (with y, x representation) to (x, y) tuple
+    """
+    return divmod(value, 1 << 4)[::-1]
+
+
+def pack_videowall_model(value):
+    """
+    Converts (x, y) tuple to one coordinates byte (with y, x representation)
+    """
+    return (value[0] * 16) + value[1]
